# Security Policy

## Reporting a Vulnerability

Please report security vulnerabilities to security@codepawl.com.

Do not open public GitHub issues for security vulnerabilities.

We will respond within 48 hours.
